Type

Struct Type 

pub struct Type {
    pub is_final: bool,
    pub supertype: Option<TypeId>,
    pub name: Option<String>,
    /* private fields */
}
A WebAssembly type definition.

With the GC proposal, types can be function types, struct types, or array types, and can participate in subtyping and recursive type groups.

Fields

is_final: bool

Whether this type is final (cannot be further subtyped). Defaults to true for types without explicit subtype declarations.

supertype: Option<TypeId>

Optional supertype that this type extends.

name: Option<String>

An optional name for debugging.

This is not really used by anything currently, but a theoretical WAT to walrus parser could keep track of the original name in the WAT.

Implementations

Source

impl Type

pub fn id(&self) -> TypeId

Get the id of this type.

pub fn kind(&self) -> &CompositeType

Get a reference to the composite type.

pub fn kind_mut(&mut self) -> &mut CompositeType

Get a mutable reference to the composite type.

pub fn params(&self) -> &[ValType]

Get the parameters to this function type.

Panics

Panics if this type is not a function type.

pub fn results(&self) -> &[ValType]

Get the results of this function type.

Panics

Panics if this type is not a function type.

pub fn as_function(&self) -> Option<&FunctionType>

Returns this type’s composite type as a function type, if it is one.

pub fn as_struct(&self) -> Option<&StructType>

Returns this type’s composite type as a struct type, if it is one.

pub fn as_array(&self) -> Option<&ArrayType>

Returns this type’s composite type as an array type, if it is one.

pub fn is_function(&self) -> bool

Whether this type is a function type.

pub fn is_struct(&self) -> bool

Whether this type is a struct type.

pub fn is_array(&self) -> bool

Whether this type is an array type.

pub fn referenced_types(&self, out: &mut Vec<TypeId>)

Collect all TypeIds that this type directly references.

This includes concrete heap types in parameters/results/fields and the supertype, if any. Used by the GC pass to transitively keep types alive.