pub struct Type {
pub is_final: bool,
pub supertype: Option<TypeId>,
pub name: Option<String>,
/* private fields */
}Expand description
A WebAssembly type definition.
With the GC proposal, types can be function types, struct types, or array types, and can participate in subtyping and recursive type groups.
Fields
is_final: boolWhether this type is final (cannot be further subtyped).
Defaults to true for types without explicit subtype declarations.
supertype: Option<TypeId>Optional supertype that this type extends.
name: Option<String>An optional name for debugging.
This is not really used by anything currently, but a theoretical WAT to walrus parser could keep track of the original name in the WAT.
Implementations
Sourceimpl Type
impl Type
Sourcepub fn kind(&self) -> &CompositeType
pub fn kind(&self) -> &CompositeType
Get a reference to the composite type.
Sourcepub fn kind_mut(&mut self) -> &mut CompositeType
pub fn kind_mut(&mut self) -> &mut CompositeType
Get a mutable reference to the composite type.
Sourcepub fn as_function(&self) -> Option<&FunctionType>
pub fn as_function(&self) -> Option<&FunctionType>
Returns this type’s composite type as a function type, if it is one.
Sourcepub fn as_struct(&self) -> Option<&StructType>
pub fn as_struct(&self) -> Option<&StructType>
Returns this type’s composite type as a struct type, if it is one.
Sourcepub fn as_array(&self) -> Option<&ArrayType>
pub fn as_array(&self) -> Option<&ArrayType>
Returns this type’s composite type as an array type, if it is one.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Whether this type is a function type.
Sourcepub fn referenced_types(&self, out: &mut Vec<TypeId>)
pub fn referenced_types(&self, out: &mut Vec<TypeId>)
Collect all TypeIds that this type directly references.
This includes concrete heap types in parameters/results/fields and the supertype, if any. Used by the GC pass to transitively keep types alive.